==> igniteui-react-charts-18.7.2.tgz: package/esm2015/lib/ScatterLineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterLineSeriesView = /*@__PURE__*/ (() => {
    class ScatterLineSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dl = new Path();
            this.dk = new Path();
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.w2 = Defaults.e;
            }
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            let a = this.br();
            this.dk.an = this.dl.an;
            this.dk._stroke = a;
            this.dk.ad = this.e.ic + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.dk);
                }
                else {
                    a.t(this.dl);
                }
            }
        }
        c9(a) {
            super.c9(a);
            this.dl.an = null;
            this.dk.an = null;
        }
        an(a) {
            super.an(a);
            this.e.bb.exportPathData(a, this.dl, "shape", ["Main"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.vv = a;
            this.e.jk = 3;
            this.e.jl = 1;
            this.e.jm = 4;
            this.e.ha = false;
        }
    }
    ScatterLineSeriesView.$t = /*@__PURE__*/ markType(ScatterLineSeriesView, 'ScatterLineSeriesView', ScatterBaseView.$);
    return ScatterLineSeriesView;
})();

==> igniteui-react-charts-19.0.0.tgz: package/esm2015/lib/ScatterLineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterLineSeriesView = /*@__PURE__*/ (() => {
    class ScatterLineSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dz = new Path();
            this.dy = new Path();
        }
        a4() {
            super.a4();
            if (!this.t) {
                this.ch.xf = Defaults.e;
            }
        }
        bp() {
            super.bp();
        }
        bq() {
            super.bq();
            let a = this.b3();
            this.dy.an = this.dz.an;
            this.dy._stroke = a;
            this.dy.ad = this.f.ig + 3;
        }
        bj(a, b) {
            super.bj(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.dy);
                }
                else {
                    a.t(this.dz);
                }
            }
        }
        dm(a) {
            super.dm(a);
            this.dz.an = null;
            this.dy.an = null;
        }
        ax(a) {
            super.ax(a);
            this.f.bc.exportPathData(a, this.dz, "shape", ["Main"]);
        }
        an() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.f.v6 = a;
            this.f.jn = 3;
            this.f.jo = 1;
            this.f.jp = 4;
            this.f.hd = false;
        }
    }
    ScatterLineSeriesView.$t = /*@__PURE__*/ markType(ScatterLineSeriesView, 'ScatterLineSeriesView', ScatterBaseView.$);
    return ScatterLineSeriesView;
})();
